@@ -351,6 +351,12 @@ pub use cgroups::*;
 mod cpuinfo;
 pub use cpuinfo::*;
 
+mod crypto;
+pub use crypto::*;
+
+mod devices;
+pub use devices::*;
+
 mod diskstats;
 pub use diskstats::*;
 
@@ -378,6 +384,9 @@ pub use pressure::*;
 
 pub mod process;
 
+mod kpageflags;
+pub use kpageflags::*;
+
 pub mod sys;
 pub use sys::kernel::Version as KernelVersion;
 
